Creating a virtual machine (VM) with an operand stack and a context stack (for frames) in Java involves several key components. Below is a simplified example of how you might go about implementing such a VM. 

### 1. Define the Basic Stack Structures

We'll create two stack structures:

- **Operand Stack**: Holds operands and intermediate results during execution.
- **Context Stack**: Holds frames for each method invocation.

### 2. Create the Virtual Machine

The VM needs to support basic operations, such as pushing and popping from the stacks, and method invocation (which will push and pop from the context stack).

### 3. Define Instructions

You'll need a set of basic instructions (e.g., `PUSH`, `POP`, `ADD`, etc.) for the VM to execute.

Here’s a simplified implementation:

```java
import java.util.Stack;
import java.util.HashMap;
import java.util.Map;

class Frame {
    private Stack<Integer> operandStack = new Stack<>();
    private Map<String, Integer> localVariables = new HashMap<>();

    public Stack<Integer> getOperandStack() {
        return operandStack;
    }

    public Map<String, Integer> getLocalVariables() {
        return localVariables;
    }
}

class VirtualMachine {
    private Stack<Frame> contextStack = new Stack<>();
    private Frame currentFrame;
    
    public VirtualMachine() {
        pushNewFrame();  // The initial frame
    }

    private void pushNewFrame() {
        currentFrame = new Frame();
        contextStack.push(currentFrame);
    }

    private void popFrame() {
        contextStack.pop();
        currentFrame = contextStack.isEmpty() ? null : contextStack.peek();
    }

    public void execute(Instruction[] instructions) {
        for (Instruction instruction : instructions) {
            instruction.execute(this);
        }
    }

    public void pushOperand(int value) {
        currentFrame.getOperandStack().push(value);
    }

    public int popOperand() {
        return currentFrame.getOperandStack().pop();
    }

    public void store(String variableName, int value) {
        currentFrame.getLocalVariables().put(variableName, value);
    }

    public int load(String variableName) {
        Integer value = currentFrame.getLocalVariables().get(variableName);
        if (value == null) {
            throw new RuntimeException("Undefined variable: " + variableName);
        }
        return value;
    }

    public void callMethod(Frame newFrame, Instruction[] instructions) {
        pushNewFrame();
        execute(instructions);
        popFrame();
    }
}

interface Instruction {
    void execute(VirtualMachine vm);
}

class PushInstruction implements Instruction {
    private int value;

    public PushInstruction(int value) {
        this.value = value;
    }

    @Override
    public void execute(VirtualMachine vm) {
        vm.pushOperand(value);
    }
}

class AddInstruction implements Instruction {
    @Override
    public void execute(VirtualMachine vm) {
        int v1 = vm.popOperand();
        int v2 = vm.popOperand();
        vm.pushOperand(v1 + v2);
    }
}

class PopInstruction implements Instruction {
    @Override
    public void execute(VirtualMachine vm) {
        vm.popOperand();
    }
}

class StoreInstruction implements Instruction {
    private String variableName;

    public StoreInstruction(String variableName) {
        this.variableName = variableName;
    }

    @Override
    public void execute(VirtualMachine vm) {
        int value = vm.popOperand();
        vm.store(variableName, value);
    }
}

class LoadInstruction implements Instruction {
    private String variableName;

    public LoadInstruction(String variableName) {
        this.variableName = variableName;
    }

    @Override
    public void execute(VirtualMachine vm) {
        int value = vm.load(variableName);
        vm.pushOperand(value);
    }
}

class CallInstruction implements Instruction {
    private Instruction[] methodInstructions;

    public CallInstruction(Instruction[] methodInstructions) {
        this.methodInstructions = methodInstructions;
    }

    @Override
    public void execute(VirtualMachine vm) {
        vm.callMethod(new Frame(), methodInstructions);
    }
}

public class Main {
    public static void main(String[] args) {
        Instruction[] methodInstructions = new Instruction[] {
            new PushInstruction(4),
            new PushInstruction(6),
            new AddInstruction(),         // 4 + 6 = 10
            new StoreInstruction("result"),
        };

        Instruction[] mainInstructions = new Instruction[] {
            new PushInstruction(5),
            new CallInstruction(methodInstructions),
            new LoadInstruction("result"),
            new AddInstruction(),
        };

        VirtualMachine vm = new VirtualMachine();
        vm.execute(mainInstructions);

        System.out.println("Final result: " + vm.popOperand()); // Should print 15
    }
}
```

### Explanation:

- **Frame**: Represents the execution context for a method, holding an operand stack and local variables.
  
- **VirtualMachine**: Manages frames and both stacks (context stack and operand stack). The VM interprets the list of instructions.

- **Instruction**: An interface that represents a command to execute. Specific instructions (like `PushInstruction`, `AddInstruction`, etc.) implement this interface.

- **Main Execution**: A simple main function is created, where we define a few instructions to be executed by our VM. The `CallInstruction` demonstrates how a method would be invoked, which pushes a new frame onto the context stack.

### Summary
This code demonstrates the core structure of a simple virtual machine with an operand stack and a context stack (frames). The VM supports basic arithmetic operations, local variables, and method invocations. From here, you can extend the instruction set, implement error handling, optimize performance, and add more complex features, depending on the needs of your virtual machine.